==> Spire.Doc-11.8.1-py3-none-win_amd64.whl: spire/doc/BookmarkCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.doc.common import *
from spire.doc import *
from ctypes import *
import abc

class BookmarkCollection (  CollectionEx) :
    """
    <summary>
        A collection of <see cref="T:Spire.Doc.Bookmark" /> objects that 
            represent the bookmarks in the document.
    </summary>
    """
    @dispatch

    def get_Item(self ,name:str)->Bookmark:
        """
    <summary>
        Gets the <see cref="T:Spire.Doc.Bookmark" /> with the specified name.
    </summary>
<value></value>
        """
        namePtr = StrToPtr(name)
        GetDllLibDoc().BookmarkCollection_get_Item.argtypes=[c_void_p ,c_char_p]
        GetDllLibDoc().BookmarkCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibDoc().BookmarkCollection_get_Item(self.Ptr, namePtr)
        ret = None if intPtr==None else Bookmark(intPtr)
        return ret


    @dispatch

    def get_Item(self ,index:int)->Bookmark:
        """
    <summary>
        Gets the <see cref="T:Spire.Doc.Bookmark" /> at the specified index.
    </summary>
<value></value>
        """
        
        GetDllLibDoc().BookmarkCollection_get_ItemI.argtypes=[c_void_p ,c_int]
        GetDllLibDoc().BookmarkCollection_get_ItemI.restype=c_void_p
        intPtr = GetDllLibDoc().BookmarkCollection_get_ItemI(self.Ptr, index)
        ret = None if intPtr==None else Bookmark(intPtr)
        return ret



    def FindByName(self ,name:str)->'Bookmark':
        """
    <summary>
        Finds <see cref="T:Spire.Doc.Bookmark" /> object by specified name
    </summary>
    <param name="name">The bookmark name</param>
    <returns></returns>
        """
        namePtr = StrToPtr(name)
        GetDllLibDoc().BookmarkCollection_FindByName.argtypes=[c_void_p ,c_char_p]
        GetDllLibDoc().BookmarkCollection_FindByName.restype=c_void_p
        intPtr = GetDllLibDoc().BookmarkCollection_FindByName(self.Ptr, namePtr)
        ret = None if intPtr==None else Bookmark(intPtr)
        return ret



    def RemoveAt(self ,index:int):
        """
    <summary>
        Removes a bookmark at the specified index.
    </summary>
    <param name="index">The index.</param>
        """
        
        GetDllLibDoc().BookmarkCollection_RemoveAt.argtypes=[c_void_p ,c_int]
        GetDllLibDoc().BookmarkCollection_RemoveAt(self.Ptr, index)


    def Remove(self ,bookmark:'Bookmark'):
        """
    <summary>
        Removes the specified bookmark.
    </summary>
    <param name="bookmark">The bookmark.</param>
        """
        intPtrbookmark:c_void_p = bookmark.Ptr

        GetDllLibDoc().BookmarkCollection_Remove.argtypes=[c_void_p ,c_void_p]
        GetDllLibDoc().BookmarkCollection_Remove(self.Ptr, intPtrbookmark)

    def Clear(self):
        """
    <summary>
        Removes all bookmarks from the document. 
    </summary>
        """
        GetDllLibDoc().BookmarkCollection_Clear.argtypes=[c_void_p]
        GetDllLibDoc().BookmarkCollection_Clear(self.Ptr)

==> Spire.Doc-11.10.0-py3-none-win_amd64.whl: spire/doc/BookmarkCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.doc.common import *
from spire.doc import *
from ctypes import *
import abc

class BookmarkCollection(CollectionEx):
    """
    A collection of Bookmark objects that represent the bookmarks in the document.
    """

    @dispatch
    def get_Item(self, name: str) -> Bookmark:
        """
        Gets the Bookmark with the specified name.
        """
        namePtr = StrToPtr(name)
        GetDllLibDoc().BookmarkCollection_get_Item.argtypes=[c_void_p ,c_char_p]
        GetDllLibDoc().BookmarkCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibDoc().BookmarkCollection_get_Item(self.Ptr, namePtr)
        ret = None if intPtr==None else Bookmark(intPtr)
        return ret

    @dispatch
    def get_Item(self, index: int) -> Bookmark:
        """
        Gets the Bookmark at the specified index.
        """
        
        GetDllLibDoc().BookmarkCollection_get_ItemI.argtypes=[c_void_p ,c_int]
        GetDllLibDoc().BookmarkCollection_get_ItemI.restype=c_void_p
        intPtr = GetDllLibDoc().BookmarkCollection_get_ItemI(self.Ptr, index)
        ret = None if intPtr==None else Bookmark(intPtr)
        return ret

    def FindByName(self, name: str) -> 'Bookmark':
        """
        Finds Bookmark object by specified name.
        :param name: The bookmark name
        :returns: The found Bookmark object
        """
        namePtr = StrToPtr(name)
        GetDllLibDoc().BookmarkCollection_FindByName.argtypes=[c_void_p ,c_char_p]
        GetDllLibDoc().BookmarkCollection_FindByName.restype=c_void_p
        intPtr = GetDllLibDoc().BookmarkCollection_FindByName(self.Ptr, namePtr)
        ret = None if intPtr==None else Bookmark(intPtr)
        return ret

    def RemoveAt(self, index: int):
        """
        Removes a bookmark at the specified index.
        :param index: The index.
        """
        
        GetDllLibDoc().BookmarkCollection_RemoveAt.argtypes=[c_void_p ,c_int]
        GetDllLibDoc().BookmarkCollection_RemoveAt(self.Ptr, index)

    def Remove(self, bookmark: 'Bookmark'):
        """
        Removes the specified bookmark.
        :param bookmark: The bookmark.
        """
        intPtrbookmark:c_void_p = bookmark.Ptr

        GetDllLibDoc().BookmarkCollection_Remove.argtypes=[c_void_p ,c_void_p]
        GetDllLibDoc().BookmarkCollection_Remove(self.Ptr, intPtrbookmark)

    def Clear(self):
        """
        Removes all bookmarks from the document.
        """
        GetDllLibDoc().BookmarkCollection_Clear.argtypes=[c_void_p]
        GetDllLibDoc().BookmarkCollection_Clear(self.Ptr)
